@@ -68,26 +68,6 @@ class MssmClinical(Dataset):
                 df = df.set_index("case_id")
                 df.index.name = 'Patient_ID'
                 df = df.sort_values(by=["Patient_ID"])
-                
-                '''
-                # make Sample_Tumor_Normal column
-                if tumor_codes[filter_type] not in ('HCC','CO','OV'): # sample types not distinguished in clinical_Pan-cancer.Dec2020.tsv
-                    if tumor_codes[filter_type] in ('GBM', 'BR'): # only has tumor samples 
-                        df['Sample_Tumor_Normal'] = 'Tumor'
-                    else:
-                        # Get list of patient_IDs with normal sample. Add suffix to distinguish. 
-                        normal = df.loc[df['discovery_study/type_of_analyzed_samples'].isin(['Normal', 'Tumor_and_Normal'])]
-                        normal = normal.sort_values(by=["Patient_ID"])
-                        normal['Sample_Tumor_Normal'] = 'Normal'
-                        normal = normal[['Sample_Tumor_Normal']] # keep only Sample_Tumor_Normal col
-                        indices = list(normal.index) 
-                        indices = [e+'.N' for e in indices] # Add ".N" to indices
-                        normal.index = indices
-                        # tumor samples
-                        tumor = df.loc[df['discovery_study/type_of_analyzed_samples'].isin(['Tumor', 'Tumor_and_Normal'])]
-                        tumor = tumor.sort_values(by=["Patient_ID"])
-                        tumor['Sample_Tumor_Normal'] = 'Tumor'
-                        df = tumor.append(normal) # append only the annotated patient_ID for normals (other information is with tumor and normals have nan for values in clinical table)'''
                 self._data["clinical"] = df                      
         
                 
@@ -229,41 +209,5 @@ class MssmClinical(Dataset):
         dem = dem.rename(columns={'history_source':'med_history_source'}) # ?? ok to rename?
         self._data['demographic'] = dem           
 
-        # Get a union of all dataframes' indices, with duplicates removed
-        ###FILL: If there are any tables whose index values you don't want
-        ### included in the master index, pass them to the optional 'exclude'
-        ### parameter of the unionize_indices function. This was useful, for
-        ### example, when some datasets' followup data files included samples
-        ### from cohorts that weren't in any data tables besides the followup
-        ### table, so we excluded the followup table from the master index since
-        ### there wasn't any point in creating empty representative rows for
-        ### those samples just because they existed in the followup table.
-        #master_index = unionize_indices(self._data) 
-
-        # Use the master index to reindex the clinical dataframe, so the clinical dataframe has a record of every sample in the dataset. Rows that didn't exist before (such as the rows for normal samples) are filled with NaN.
-        #new_clinical = self._data["clinical"]
-        #new_clinical = new_clinical.reindex(master_index)
-
-        # Edit the format of the Patient_IDs to have normal samples marked the same way as in other datasets. 
-        
-        ###FILL: You will need to pass the proper parameters to correctly
-        ### reformat the patient IDs in your dataset. The standard format is to
-        ### have the string '.N' appended to the end of the normal patient IDs,
-        ### e.g. the  normal patient ID corresponding to C3L-00378 would be
-        ### C3L-00378.N (this way we can easily match two samples from the same
-        ### patient). The example code below is for a dataset where all the
-        ### normal samples have  an "N" prepended to the patient IDs. The
-        ### reformat_normal_patient_ids function erases that and puts a ".N" at
-        ### the end. See cptac/dataframe_tools.py for further function
-        ### documentation.
-        ###START EXAMPLE CODE###################################################
-#        self._data = reformat_normal_patient_ids(self._data, existing_identifier="N", existing_identifier_location="start")
-        ###END EXAMPLE CODE#####################################################
-
-        # Call function from dataframe_tools.py to sort all tables first by sample status, and then by the index
-#        self._data = sort_all_rows(self._data)
-
-        # Call function from dataframe_tools.py to standardize the names of the index and column axes
-#        self._data = standardize_axes_names(self._data)
 
         print(" " * len(formatting_msg), end='\r') # Erase the formatting message
