@@ -32,7 +32,7 @@ class UcecConf(Dataset):
         # Set some needed variables, and pass them to the parent Dataset class __init__ function
 
         # This keeps a record of all versions that the code is equipped to handle. That way, if there's a new data release but they didn't update their package, it won't try to parse the new data version it isn't equipped to handle.
-        valid_versions = ["1.0", "1.1", "1.2"]
+        valid_versions = ["1.0", "1.1", "1.2", "2.0", "2.0.1"]
 
         data_files = {
             "1.0": [
@@ -63,14 +63,12 @@ class UcecConf(Dataset):
             "UCEC_confirmatory_meta_table_v1.1.xlsx",
             "UCEC_confirmatory_methylation_gene_level_beta_value_tumor_v1.1.cct.gz",
             "UCEC_confirmatory_miRNAseq_miRNA_TPM_log2(x+1)_tumor_normal_v1.1.cct.gz",
-            #"UCEC_confirmatory_nglycoform-site_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
             "UCEC_confirmatory_phospho_gene_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
             "UCEC_confirmatory_phospho_site_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
             "UCEC_confirmatory_proteomics_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
             "UCEC_confirmatory_RNAseq_circRNA_RSEM_UQ_log2(x+1)_tumor_normal_v1.1.cct.gz",
             "UCEC_confirmatory_RNAseq_gene_fusion_tumor_v1.1.txt.gz",
             "UCEC_confirmatory_RNAseq_gene_RSEM_removed_circRNA_UQ_log2(x+1)_tumor_normal_v1.1.cct.gz",
-            #"UCEC_confirmatory_RNAseq_isoform_FPKM_removed_circRNA_log2(x+1)_tumor_normal_v1.1.cct.gz",
             "UCEC_confirmatory_SRM_Direct_tumor_v1.1.cct.gz",
             "UCEC_confirmatory_SRM_IMAC_tumor_v1.1.cct.gz",
             "UCEC_confirmatory_SRM_PRISM_tumor_v1.1.cct.gz",
@@ -78,7 +76,6 @@ class UcecConf(Dataset):
             "UCEC_confirmatory_WES_cnv_log2_ratio_tumor_v1.1.cct.gz",
             "UCEC_confirmatory_WES_somatic_mutation_gene_level_V1.1.cbt.gz",
             "UCEC_confirmatory_WES_somatic_mutation_v1.1.maf.gz",
-            #"UCEC_confirmatory_WGS_SV_tumor_v1.1.txt.gz",
             ],
         "1.2": [
             "UCEC_confirmatory_meta_table_v1.2.xlsx",
@@ -102,7 +99,48 @@ class UcecConf(Dataset):
             "UCEC_confirmatory_phospho_gene_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz",
             "UCEC_confirmatory_phospho_site_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz",
             "UCEC_confirmatory_proteomics_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz",
-
+            ],
+        "2.0": [
+            "UCEC_confirmatory_acetyl_gene_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_acetyl_site_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_meta_table_v2.0.xlsx",
+            "UCEC_confirmatory_methylation_gene_level_beta_value_tumor_v2.0.cct.gz",
+            "UCEC_confirmatory_miRNAseq_miRNA_TPM_log2(x+1)_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_phospho_gene_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_phospho_site_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_proteomics_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_RNAseq_circRNA_RSEM_UQ_log2(x+1)_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_RNAseq_gene_fusion_tumor_v2.0.txt.gz",
+            "UCEC_confirmatory_RNAseq_gene_RSEM_removed_circRNA_UQ_log2(x+1)_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_SRM_Direct_tumor_v2.0.cct.gz",
+            "UCEC_confirmatory_SRM_IMAC_tumor_v2.0.cct.gz",
+            "UCEC_confirmatory_SRM_PRISM_tumor_v2.0.cct.gz",
+#             "UCEC_confirmatory_WES_somatic_mutation_category_level_V1.2.txt.gz",
+            "UCEC_confirmatory_WES_somatic_mutation_gene_level_V1.2.cbt.gz",
+            "UCEC_confirmatory_WES_somatic_mutation_v2.0.maf.gz",
+            "UCEC_confirmatory_WGS_cnv_gistic_thresholded_tumor_v2.0.cct.gz",
+            "UCEC_confirmatory_WGS_cnv_log2_ratio_tumor_v2.0.cct.gz",
+#             "UCEC_confirmatory_WGS_SV_tumor_v2.0.txt.gz",
+            ],
+        "2.0.1": [
+            "UCEC_confirmatory_acetyl_gene_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_acetyl_site_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_meta_table_v2.0.1.xlsx",
+            "UCEC_confirmatory_methylation_gene_level_beta_value_tumor_v2.0.cct.gz",
+            "UCEC_confirmatory_miRNAseq_miRNA_TPM_log2(x+1)_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_phospho_gene_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_phospho_site_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_proteomics_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_RNAseq_circRNA_RSEM_UQ_log2(x+1)_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_RNAseq_gene_fusion_tumor_v2.0.txt.gz",
+            "UCEC_confirmatory_RNAseq_gene_RSEM_removed_circRNA_UQ_log2(x+1)_tumor_normal_v2.0.cct.gz",
+            "UCEC_confirmatory_SRM_Direct_tumor_v2.0.cct.gz",
+            "UCEC_confirmatory_SRM_IMAC_tumor_v2.0.cct.gz",
+            "UCEC_confirmatory_SRM_PRISM_tumor_v2.0.cct.gz",
+            "UCEC_confirmatory_WES_somatic_mutation_gene_level_V1.2.cbt.gz",
+            "UCEC_confirmatory_WES_somatic_mutation_v2.0.maf.gz",
+            "UCEC_confirmatory_WGS_cnv_gistic_thresholded_tumor_v2.0.cct.gz",
+            "UCEC_confirmatory_WGS_cnv_log2_ratio_tumor_v2.0.cct.gz",
             ],
         }
 
@@ -121,8 +159,9 @@ class UcecConf(Dataset):
             file_name = path_elements[-1] # The last element will be the name of the file. We'll use this to identify files for parsing in the if/elif statements below
             
             if file_name in ["UCEC_confirmatory_acetyl_gene_ratio_median_polishing_log2_tumor_normal_v1.0.cct.gz", 
-                                "UCEC_confirmatory_acetyl_gene_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
-                                "UCEC_confirmatory_acetyl_gene_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz"]:
+                             "UCEC_confirmatory_acetyl_gene_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
+                             "UCEC_confirmatory_acetyl_gene_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz",
+                             "UCEC_confirmatory_acetyl_gene_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0)
                 df = df.transpose()
                 df = df.sort_index()
@@ -132,7 +171,8 @@ class UcecConf(Dataset):
             
             elif file_name in ["UCEC_confirmatory_acetyl_site_ratio_median_polishing_log22_tumor_normal_v1.0.cct.gz", 
                                 "UCEC_confirmatory_acetyl_site_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
-                                "UCEC_confirmatory_acetyl_site_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz"]:
+                                "UCEC_confirmatory_acetyl_site_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz",
+                                "UCEC_confirmatory_acetyl_site_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0)
                 df = df.reset_index()
                 df[['Name','Database_ID','Site']] = df.idx.str.split("@", expand=True)
@@ -146,7 +186,9 @@ class UcecConf(Dataset):
             
             elif file_name in ["UCEC_confirmatory_meta_table_v1.0.xlsx", 
                                "UCEC_confirmatory_meta_table_v1.1.xlsx",
-                               "UCEC_confirmatory_meta_table_v1.2.xlsx"]:
+                               "UCEC_confirmatory_meta_table_v1.2.xlsx",
+                               "UCEC_confirmatory_meta_table_v2.0.xlsx",
+                               "UCEC_confirmatory_meta_table_v2.0.1.xlsx"]:
                 df = pd.read_excel(file_path)
                 df.insert(6, "Proteomics_Tumor_Normal", df["Group"])
                 df.loc[df['Group'] == 'Enriched_Normal', 'Idx'] = df['Idx'] + '.N'
@@ -160,7 +202,8 @@ class UcecConf(Dataset):
                 
             elif file_name in ["UCEC_confirmatory_methylation_gene_level_beta_value_tumor_v1.0.cct.gz", 
                                "UCEC_confirmatory_methylation_gene_level_beta_value_tumor_v1.1.cct.gz",
-                               "UCEC_confirmatory_methylation_gene_level_beta_value_tumor_v1.2.cct.gz"]:
+                               "UCEC_confirmatory_methylation_gene_level_beta_value_tumor_v1.2.cct.gz",
+                               "UCEC_confirmatory_methylation_gene_level_beta_value_tumor_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0, na_values='   NA')
                 df = df.transpose()
                 df.index.name = "Patient_ID"
@@ -169,7 +212,8 @@ class UcecConf(Dataset):
             
             elif file_name in ["UCEC_confirmatory_miRNAseq_miRNA_TPM_log2(x+1)_tumor_normal_v1.0.cct.gz",
                                "UCEC_confirmatory_miRNAseq_miRNA_TPM_log2(x+1)_tumor_normal_v1.1.cct.gz",
-                               "UCEC_confirmatory_miRNAseq_miRNA_TPM_log2(x+1)_tumor_normal_v1.2.cct.gz"]:
+                               "UCEC_confirmatory_miRNAseq_miRNA_TPM_log2(x+1)_tumor_normal_v1.2.cct.gz",
+                               "UCEC_confirmatory_miRNAseq_miRNA_TPM_log2(x+1)_tumor_normal_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0)
                 df = df.transpose()
                 df = df.sort_index()
@@ -179,7 +223,8 @@ class UcecConf(Dataset):
                 
             elif file_name in ["UCEC_confirmatory_phospho_gene_ratio_median_polishing_log22_tumor_normal_v1.0.cct.gz",
                                "UCEC_confirmatory_phospho_gene_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
-                               "UCEC_confirmatory_phospho_gene_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz"]:
+                               "UCEC_confirmatory_phospho_gene_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz",
+                               "UCEC_confirmatory_phospho_gene_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0)
                 df = df.transpose()
                 df = df.sort_index()
@@ -189,7 +234,8 @@ class UcecConf(Dataset):
                 
             elif file_name in ["UCEC_confirmatory_phospho_site_ratio_median_polishing_log22_tumor_normal_v1.0.cct.gz",
                                "UCEC_confirmatory_phospho_site_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
-                               "UCEC_confirmatory_phospho_site_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz"]:
+                               "UCEC_confirmatory_phospho_site_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz",
+                               "UCEC_confirmatory_phospho_site_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0)
                 df = df.reset_index()
                 df[['Name','Database_ID','Site']] = df.idx.str.split("@", expand=True)
@@ -203,7 +249,8 @@ class UcecConf(Dataset):
                 
             elif file_name in ["UCEC_confirmatory_proteomics_ratio_median_polishing_log22_tumor_normal_v1.0.cct.gz",
                                "UCEC_confirmatory_proteomics_ratio_median_polishing_log2_tumor_normal_v1.1.cct.gz",
-                               "UCEC_confirmatory_proteomics_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz"]:
+                               "UCEC_confirmatory_proteomics_ratio_median_polishing_log2_tumor_normal_v1.2.cct.gz",
+                               "UCEC_confirmatory_proteomics_ratio_median_polishing_log2_tumor_normal_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0)
                 df = df.transpose()
                 df = df.sort_index()
@@ -213,7 +260,8 @@ class UcecConf(Dataset):
                 
             elif file_name in ["UCEC_confirmatory_RNAseq_circRNA_RSEM_UQ_log2(x+1)_tumor_normal_v1.0.cct.gz",
                                "UCEC_confirmatory_RNAseq_circRNA_RSEM_UQ_log2(x+1)_tumor_normal_v1.1.cct.gz",
-                               "UCEC_confirmatory_RNAseq_circRNA_RSEM_UQ_log2(x+1)_tumor_normal_v1.2.cct.gz"]:
+                               "UCEC_confirmatory_RNAseq_circRNA_RSEM_UQ_log2(x+1)_tumor_normal_v1.2.cct.gz",
+                               "UCEC_confirmatory_RNAseq_circRNA_RSEM_UQ_log2(x+1)_tumor_normal_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0)
                 df = df.transpose()
                 df.index.name = "Patient_ID"
@@ -222,7 +270,8 @@ class UcecConf(Dataset):
                 
             elif file_name in ["UCEC_confirmatory_RNAseq_gene_fusion_tumor_v1.0.txt.gz", 
                                "UCEC_confirmatory_RNAseq_gene_fusion_tumor_v1.1.txt.gz",
-                               "UCEC_confirmatory_RNAseq_gene_fusion_tumor_v1.2.txt.gz"]:
+                               "UCEC_confirmatory_RNAseq_gene_fusion_tumor_v1.2.txt.gz",
+                               "UCEC_confirmatory_RNAseq_gene_fusion_tumor_v2.0.txt.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0)
                 df = df.reset_index()
                 df = df.set_index("Sample")
@@ -232,7 +281,8 @@ class UcecConf(Dataset):
                 
             elif file_name in ["UCEC_confirmatory_RNAseq_gene_RSEM_removed_circRNA_UQ_log2(x+1)_tumor_normal_v1.0.cct.gz", 
                                "UCEC_confirmatory_RNAseq_gene_RSEM_removed_circRNA_UQ_log2(x+1)_tumor_normal_v1.1.cct.gz",
-                               "UCEC_confirmatory_RNAseq_gene_RSEM_removed_circRNA_UQ_log2(x+1)_tumor_normal_v1.2.cct.gz"]:
+                               "UCEC_confirmatory_RNAseq_gene_RSEM_removed_circRNA_UQ_log2(x+1)_tumor_normal_v1.2.cct.gz",
+                               "UCEC_confirmatory_RNAseq_gene_RSEM_removed_circRNA_UQ_log2(x+1)_tumor_normal_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t', index_col=0)
                 df = df.transpose()
                 df = df.sort_index()
@@ -241,7 +291,9 @@ class UcecConf(Dataset):
                 self._data["transcriptomics"] = df
                 
             # Targeted proteomics is the direct and PRISM SRM data
-            elif file_name in ["UCEC_confirmatory_SRM_Direct_tumor_v1.1.cct.gz", "UCEC_confirmatory_SRM_Direct_tumor_v1.2.cct.gz"]:
+            elif file_name in ["UCEC_confirmatory_SRM_Direct_tumor_v1.1.cct.gz",
+                               "UCEC_confirmatory_SRM_Direct_tumor_v1.2.cct.gz",
+                               "UCEC_confirmatory_SRM_Direct_tumor_v2.0.cct.gz",]:
                 df_direct = pd.read_csv(file_path, sep='\t')
                 df_direct[['Name','Peptide']] = df_direct['idx'].str.rsplit("-", 1, expand=True)
                 df_direct = df_direct.set_index(["Name", "Peptide"])
@@ -260,7 +312,9 @@ class UcecConf(Dataset):
                 else:
                     self._data["targeted_proteomics"] = df_direct
                 
-            elif file_name in ["UCEC_confirmatory_SRM_PRISM_tumor_v1.1.cct.gz", "UCEC_confirmatory_SRM_PRISM_tumor_v1.2.cct.gz"]:
+            elif file_name in ["UCEC_confirmatory_SRM_PRISM_tumor_v1.1.cct.gz",
+                               "UCEC_confirmatory_SRM_PRISM_tumor_v1.2.cct.gz",
+                               "UCEC_confirmatory_SRM_PRISM_tumor_v2.0.cct.gz",]:
                 df_prism = pd.read_csv(file_path, sep='\t')
                 df_prism[['Name','Peptide']] = df_prism['idx'].str.rsplit("-", 1, expand=True)
                 df_prism = df_prism.set_index(["Name", "Peptide"])
@@ -279,7 +333,9 @@ class UcecConf(Dataset):
                 else:
                     self._data["targeted_proteomics"] = df_prism
                     
-            elif file_name in ["UCEC_confirmatory_SRM_IMAC_tumor_v1.1.cct.gz", "UCEC_confirmatory_SRM_IMAC_tumor_v1.2.cct.gz"]:
+            elif file_name in ["UCEC_confirmatory_SRM_IMAC_tumor_v1.1.cct.gz",
+                               "UCEC_confirmatory_SRM_IMAC_tumor_v1.2.cct.gz",
+                               "UCEC_confirmatory_SRM_IMAC_tumor_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t')
                 df.at[0,'idx'] = "FPSS[+80]PLRIPGGNIY[+80]ISPLK"
                 df['Name'] = "RB1"
@@ -293,7 +349,8 @@ class UcecConf(Dataset):
                 
             elif file_name in ["UCEC_confirmatory_WES_cnv_gistic_thresholded_tumor_v1.0.cct.gz", 
                                "UCEC_confirmatory_WES_cnv_gistic_thresholded_tumor_v1.1.cct.gz",
-                               "UCEC_confirmatory_WGS_cnv_gistic_thresholded_tumor_v1.2.cct.gz"]:
+                               "UCEC_confirmatory_WGS_cnv_gistic_thresholded_tumor_v1.2.cct.gz",
+                               "UCEC_confirmatory_WGS_cnv_gistic_thresholded_tumor_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t')
                 df[['Name','Chromosome']] = df.idx.str.split("|", expand=True)
                 df = df.set_index(["Name"])
@@ -305,7 +362,8 @@ class UcecConf(Dataset):
                 
             elif file_name in ["UCEC_confirmatory_WES_cnv_log2_ratio_tumor_v1.0.cct.gz", 
                                "UCEC_confirmatory_WES_cnv_log2_ratio_tumor_v1.1.cct.gz",
-                               "UCEC_confirmatory_WGS_cnv_log2_ratio_tumor_v1.2.cct.gz"]:
+                               "UCEC_confirmatory_WGS_cnv_log2_ratio_tumor_v1.2.cct.gz",
+                               "UCEC_confirmatory_WGS_cnv_log2_ratio_tumor_v2.0.cct.gz",]:
                 df = pd.read_csv(file_path, sep='\t')
                 df[['Name','Chromosome']] = df.idx.str.split("|", expand=True)
                 df = df.set_index(["Name"])
@@ -326,7 +384,8 @@ class UcecConf(Dataset):
 
             elif file_name in ["UCEC_confirmatory_WES_somatic_mutation_v1.0.maf.gz", 
                                "UCEC_confirmatory_WES_somatic_mutation_v1.1.maf.gz",
-                               "UCEC_confirmatory_WES_somatic_mutation_v1.2.maf.gz"]:
+                               "UCEC_confirmatory_WES_somatic_mutation_v1.2.maf.gz",
+                               "UCEC_confirmatory_WES_somatic_mutation_v2.0.maf.gz",]:
                 df = pd.read_csv(file_path, sep='\t', dtype={88:object})
                 df = df[['Tumor_Sample_Barcode','Hugo_Symbol','Variant_Classification','HGVSp_Short']]
                 df['Tumor_Sample_Barcode'] = df['Tumor_Sample_Barcode'].apply(lambda s: s[:-2])
